@@ -5,7 +5,7 @@ use warnings;
 
 sub deprecation_flag {
     # Probably won't work on win32 :)
-    return -e 'inc/.author' ? () : (quiet_deprecation => 1);
+    return ! $ENV{TEST_NO_AUTHOR} && -e 'inc/.author' ? () : (quiet_deprecation => 1);
 }
 
 1;
